/*
 * Copyright © 2020 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.domain;

/**
 * Checks if a move returned by a {@link Strategy} is a supported move, i.e. allowed by the underlying game engine. As
 * the {@link Move} interface could be implemented freely, a {@link Strategy} could cheat by creating a custom move that
 * manipulates the {@link State} of a game in an unexpected way. A {@link MoveChecker} is responsible for detecting and
 * preventing such malicious behaviour.
 *
 * @param <P> The type of game players.
 * @param <S> The type of game states.
 * @param <M> The type of game moves.
 */
@FunctionalInterface
public interface MoveChecker<P extends Player<P>, S extends State<P, S>, M extends Move<P, S>> {

    /**
     * Checks if the move passed is one of the predefined moves offered by the game engine.
     *
     * @param move The move to check.
     * @return {@code true} if the move is supported, else {@code false}.
     */
    boolean check(M move);
}
