/*
 * Copyright © 2020 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.ui.type;

/**
 * Visits a {@link FieldType}.
 */
public interface FieldTypeVisitor {

    /**
     * Handles a {@link StringFieldType}.
     *
     * @param fieldType The field type.
     * @throws FieldTypeException Wraps an exception thrown while processing {@code fieldType}.
     */
    void handle(StringFieldType fieldType) throws FieldTypeException;

    /**
     * Handles a {@link IntegerFieldType}.
     *
     * @param fieldType The field type.
     * @throws FieldTypeException Wraps an exception thrown while processing {@code fieldType}.
     */
    void handle(IntegerFieldType fieldType) throws FieldTypeException;

    /**
     * Handles a {@link BooleanFieldType}.
     *
     * @param fieldType The field type.
     * @throws FieldTypeException Wraps an exception thrown while processing {@code fieldType}.
     */
    void handle(BooleanFieldType fieldType) throws FieldTypeException;

    /**
     * Handles a {@link ObjectFieldType}.
     *
     * @param fieldType The field type.
     * @throws FieldTypeException Wraps an exception thrown while processing {@code fieldType}.
     */
    void handle(ObjectFieldType fieldType) throws FieldTypeException;

    /**
     * Handles a {@link FieldTypeWithValidator}.
     *
     * @param fieldType The field type.
     * @throws FieldTypeException Wraps an exception thrown while processing {@code fieldType}.
     */
    void handle(FieldTypeWithValidator<?> fieldType) throws FieldTypeException;
}
